==> PyICU-0.8.1.tar.gz: PyICU-0.8.1/calendar.h <==
/* ====================================================================
 * Copyright (c) 2004-2007 Open Source Applications Foundation.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions: 
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software. 
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 * ====================================================================
 */

#ifndef _calendar_h
#define _calendar_h

class t_timezone : public _wrapper {
public:
    TimeZone *object;
};

extern PyTypeObject CalendarType;
extern PyTypeObject TimeZoneType;


PyObject *wrap_Calendar(Calendar *, int);
PyObject *wrap_TimeZone(TimeZone *, int);
PyObject *wrap_TimeZone(TimeZone *);
PyObject *wrap_TimeZone(const TimeZone &);
PyObject *t_timezone_createTimeZone(PyTypeObject *type, PyObject *arg);

void _init_calendar(PyObject *m);


#endif /* _calendar_h */

==> PyICU-1.9.4.tar.gz: PyICU-1.9.4/calendar.h <==
/* ====================================================================
 * Copyright (c) 2004-2010 Open Source Applications Foundation.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions: 
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software. 
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 * ====================================================================
 */

#ifndef _calendar_h
#define _calendar_h

class t_timezone : public _wrapper {
public:
    TimeZone *object;
};

extern PyTypeObject CalendarType_;
extern PyTypeObject TimeZoneType_;


PyObject *wrap_Calendar(Calendar *, int);
PyObject *wrap_TimeZone(TimeZone *, int);
PyObject *wrap_TimeZone(TimeZone *);
PyObject *wrap_TimeZone(const TimeZone &);
PyObject *t_timezone_createTimeZone(PyTypeObject *type, PyObject *arg);

void _init_calendar(PyObject *m);


#endif /* _calendar_h */
